@@ -3,7 +3,7 @@ use std::fs::File;
 use vrp_core::models::examples::create_example_problem;
 
 #[test]
-fn can_read_config() {
+fn can_read_full_config() {
     let file = File::open("../examples/data/config/config.full.json").expect("cannot read config from file");
 
     let config = read_config(BufReader::new(file)).unwrap();
@@ -88,6 +88,10 @@ fn can_read_config() {
     let termination = config.termination.expect("no termination config");
     assert_eq!(termination.max_time, Some(300));
     assert_eq!(termination.max_generations, Some(3000));
+
+    let parallelism = config.environment.expect("no environment config").parallelism.expect("no parallelism config");
+    assert_eq!(parallelism.num_thread_pools, 6);
+    assert_eq!(parallelism.threads_per_pool, 8);
 }
 
 #[test]
